@@ -14,6 +14,10 @@ use Moose::Util::TypeConstraints;
 
 extends 'HPC::Runner';
 
+with 'MooseX::Getopt';
+with 'MooseX::Getopt::Usage';
+with 'MooseX::Getopt::Usage::Role::Man';
+
 =head1 NAME
 
 HPC::Runner::Threads - Job submission using threads
@@ -24,13 +28,13 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.34';
+our $VERSION = '2.35';
 
 =head1 SYNOPSIS
 
 Use Parallel::ForkManager to run arbitrary bash commands
 
-=head1 Variables
+=head1 Attributes
 
 =cut
 
@@ -41,7 +45,7 @@ How frequently to test for a thread having exited the queue in seconds. Defaults
 =cut
 
 has 'twait' => (
-    is => 'rw', 
+    is => 'rw',
     isa => 'Int',
     lazy => 1,
     required => 1,
@@ -61,14 +65,12 @@ has 'threads' => (
     lazy => 1,
     default => sub {
         my $self = shift;
-        return new Parallel::ForkManager($self->procs); 
+        return new Parallel::ForkManager($self->procs);
     }
 );
 
 =head1 SUBROUTINES/METHODS
 
-=cut
-
 =head2 go
 
 This is the main application. It starts the logging, build the threads, parses the file, runs the commands, and finishes logging.
@@ -129,7 +131,7 @@ sub parse_file_threads{
                 $self->log->info("Enqueuing command:\n".$self->cmd);
                 $self->run_command_threads;
                 $self->clear_cmd;
-                $self->inc_counter; 
+                $self->inc_counter;
             }
         }
         else{
@@ -143,14 +145,14 @@ sub parse_file_threads{
                 $self->clear_cmd;
                 $self->threads->wait_all_children;
                 $self->log->info("All children are out of the pool!");
-                $self->inc_counter; 
+                $self->inc_counter;
 
             }
             else{
                 $self->log->info("Enqueuing command:\n".$self->cmd);
                 $self->run_command_threads;
                 $self->clear_cmd;
-                $self->inc_counter; 
+                $self->inc_counter;
             }
         }
     }
@@ -203,7 +205,7 @@ sub build_threads{
 
 =head1 See Also
 
-Parallel::ForkManager
+L<Parallel::ForkManager>, L<HPC::Runner::GnuParallel>
 
 =head1 AUTHOR
 
@@ -245,14 +247,16 @@ L<http://search.cpan.org/dist/HPC-Runner-Threads/>
 
 =back
 
+=head1 Acknowledgements
 
-=head1 ACKNOWLEDGEMENTS
-
-This module was originally developed at and for Weill Cornell Medical College in Qatar. With approval from WCMC-Q, this information was generalized and put on github, for which the authors would like to express their gratitude.
+This module was originally developed at and for Weill Cornell Medical
+College in Qatar within ITS Advanced Computing Team. With approval from
+WCMC-Q, this information was generalized and put on github, for which
+the authors would like to express their gratitude.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Jillian Rowe.
+Copyright 2014 Weill Cornell Medical College Qatar.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
@@ -292,5 +296,3 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 =cut
-
-# End of Runner::Threads
